import {
  __export,
  matcherHint,
  printReceived
} from "./chunk-JLEAPMES.js";

// src/matchers.ts
var matchers_exports = {};
__export(matchers_exports, {
  toHaveNoViolations: () => toHaveNoViolations
});

// src/to-have-no-violations.ts
import chalk from "chalk";
function toHaveNoViolations(results) {
  if (typeof results.violations === "undefined") {
    throw new Error(
      "Unexpected aXe results object. No violations property found.\nDid you change the `reporter` in your aXe configuration?"
    );
  }
  let violations = filterViolations(
    results.violations,
    // `impactLevels` is not a valid toolOption but one we add to the config
    // when calling `run`. axe just happens to pass this along. Might be a safer
    // way to do this since it's not documented API.
    // @ts-expect-error
    results.toolOptions?.impactLevels ?? []
  );
  function reporter(violations2) {
    if (violations2.length === 0) {
      return [];
    }
    let lineBreak = "\n\n";
    let horizontalLine = "\u2500\u2500\u2500\u2500\u2500\u2500\u2500\u2500";
    return violations2.map((violation) => {
      let errorBody = violation.nodes.map((node) => {
        let selector = node.target.join(", ");
        let expectedText = `Expected the HTML found at $('${selector}') to have no violations:` + lineBreak;
        return expectedText + chalk.grey(node.html) + lineBreak + `Received:` + lineBreak + printReceived(`${violation.help} (${violation.id})`) + lineBreak + chalk.yellow(node.failureSummary) + lineBreak + (violation.helpUrl ? `You can find more information on this issue here: 
${chalk.blue(
          violation.helpUrl
        )}` : "");
      }).join(lineBreak);
      return errorBody;
    }).join(lineBreak + horizontalLine + lineBreak);
  }
  let formatedViolations = reporter(violations);
  let pass = formatedViolations.length === 0;
  function message() {
    if (pass) {
      return;
    }
    return (
      // eslint-disable-next-line no-useless-concat
      matcherHint(".toHaveNoViolations") + `

${formatedViolations}`
    );
  }
  return { actual: violations, message, pass };
}
function filterViolations(violations, impactLevels) {
  if (impactLevels && impactLevels.length > 0) {
    return violations.filter((v) => impactLevels.includes(v.impact));
  }
  return violations;
}

export {
  toHaveNoViolations,
  matchers_exports
};
//# sourceMappingURL=chunk-5JYYWIT7.js.map